@@ -1,22 +1,22 @@
-#  
+#
 #  Copyright (c) 2011 Edward Langley
 #  All rights reserved.
-#  
+#
 #  Redistribution and use in source and binary forms, with or without
 #  modification, are permitted provided that the following conditions
 #  are met:
-#  
+#
 #  Redistributions of source code must retain the above copyright notice,
 #  this list of conditions and the following disclaimer.
-#  
+#
 #  Redistributions in binary form must reproduce the above copyright
 #  notice, this list of conditions and the following disclaimer in the
 #  documentation and/or other materials provided with the distribution.
-#  
+#
 #  Neither the name of the project's author nor the names of its
 #  contributors may be used to endorse or promote products derived from
 #  this software without specific prior written permission.
-#  
+#
 #  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 #  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 #  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
@@ -28,41 +28,53 @@
 #  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 #  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 #  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-#  
+#
 #
 
 import json
 from jsonrpc import proxy
 import argparse
 
+
 def main(host, path=None, args=None):
-	proxy_ = proxy.JSONRPCProxy(host, path)
-	return proxy_
+    proxy_ = proxy.JSONRPCProxy(host, path)
+    return proxy_
+
 
 def iterate(iter_):
-	if not hasattr(iter_, 'next'): iter_ = iter(iter_)
-	rollback = []
-	try:
-		while True:
-			to_yield = None
-			if rollback != []:
-				to_yield = rollback.pop(0)
-			else:
-				to_yield = next(iter_)
+    if not hasattr(iter_, "next"):
+        iter_ = iter(iter_)
+    rollback = []
+    try:
+        while True:
+            to_yield = None
+            if rollback != []:
+                to_yield = rollback.pop(0)
+            else:
+                to_yield = next(iter_)
+
+            result = yield to_yield
+            while result is not None:
+                rollback.append(result)
+                result = yield
+    except StopIteration:
+        raise
 
 
-			result = (yield to_yield)
-			while result is not None:
-				rollback.append(result)
-				result = yield
-	except StopIteration: raise
+if __name__ == "__main__":
+    import sys
 
-if __name__ == '__main__':
-	import sys
-	parser = argparse.ArgumentParser()
-	parser.add_argument('-p', '--path', dest='path', help='path to the JSON-RPC server', nargs='?', default='/jsonrpc')
-	parser.add_argument('host', metavar='HOST')
-	args = parser.parse_args(sys.argv[1:])
+    parser = argparse.ArgumentParser()
+    parser.add_argument(
+        "-p",
+        "--path",
+        dest="path",
+        help="path to the JSON-RPC server",
+        nargs="?",
+        default="/jsonrpc",
+    )
+    parser.add_argument("host", metavar="HOST")
+    args = parser.parse_args(sys.argv[1:])
 
-	print(args)
-	server = main(args.host, args.path)
+    print(args)
+    server = main(args.host, args.path)
